==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/qt/iqtwidgettexteditorsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Qt-bases Text editor widget subject
//

#ifndef IQTWIDGETTEXTEDITORSUBJECT_H
#define IQTWIDGETTEXTEDITORSUBJECT_H


#include "iqt.h"

#ifdef IQT_3
#include <qtextedit.h>
#else
#include <Qt3Support/Q3TextEdit>
#define QTextEdit Q3TextEdit
#endif
#include "ibgwidgettexteditorsubject.h"


class iggWidgetTextEditor;

class iqtSyntaxHighlighter;

class QEvent;
class QKeyEvent;
class QMouseEvent;
class QTextEdit;


class iqtWidgetTextEditorSubject : public QTextEdit, public ibgWidgetTextEditorSubject
{

	Q_OBJECT

	friend class iggSubjectFactory;

public:

	virtual ~iqtWidgetTextEditorSubject();

	virtual bool AppendBreaksLine() const;
	virtual bool SupportsHTML() const;
	virtual bool TextModified() const;

	//
	//  Text manipulations
	//
	virtual void Clear();
	virtual void SetModified(bool s);
	virtual void SetText(const iString &text);
	virtual iString GetText() const;
	virtual void AppendText(const iString &text, bool scroll = true);

	//
	//  Line-by-line manipulation
	//
	virtual int GetNumberOfLines() const;
	virtual void RemoveLine(int n);
	virtual iString GetLine(int n) const;

	//
	//  Text attribute manipulations
	//
	virtual void SetBoldText(bool s);
	virtual void SetTextColor(const iColor &color);
	virtual void SetPointSize(int s);
	virtual void SetLineColor(int line, const iColor &color);
	virtual void UnSetLineColor(int line);
	virtual iColor GetLineColor(int line) const;

	//
	//  Selection & cursor location
	//
	virtual void Select(int paraFrom, int indexFrom, int paraTo, int indexTo, bool leftJustified = false, int selNum = 0);
	virtual void GetCursorPosition(int &para, int &index);

	//
	//  Syntax highlighting
	//
	virtual void HighlightSyntax(bool s);
	virtual void AddKeyword(const iString &word, int category);
	virtual void AddCategory(const iColor &color);
	virtual void HighlightComments(const iString &comment, const iColor &color);
	virtual void HighlightStrings(const iColor &color);

	//
	//  Editing functions
	//
	virtual bool HasEditingFunction(int type) const;
	virtual void UseEditingFunction(int type);

	//
	//  Search & find
	//
	virtual bool Find(const iString &text, bool cs, bool wo, bool forward, int &para, int &index);

protected:

	iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode);

	iqtSyntaxHighlighter *mSyntaxHighlighter;
	const int mMode;

	//
	//  Qt specific
	//
	virtual void enterEvent(QEvent *);
	virtual void keyPressEvent(QKeyEvent *e);
	virtual void contentsMousePressEvent(QMouseEvent *e);
	virtual void contentsMouseReleaseEvent(QMouseEvent *e);
	virtual void contentsMouseDoubleClickEvent(QMouseEvent *e);

public slots:

	void OnTextChanged();
	void OnSelectionChanged();
	void OnCursorPositionChanged(int, int);
	void OnReturnPressed();
};

#endif  //  IQTWIDGETTEXTEDITORSUBJECT_H

==> ifrit_3.2.8.orig.tar.gz: ifrit-3.2.8/shells/qt/iqtwidgettexteditorsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Qt-bases Text editor widget subject
//

#ifndef IQTWIDGETTEXTEDITORSUBJECT_H
#define IQTWIDGETTEXTEDITORSUBJECT_H


#include "iqt.h"

#ifdef IQT_3
#include <qtextedit.h>
#else
#include <Qt3Support/Q3TextEdit>
#define QTextEdit Q3TextEdit
#endif
#include "ibgwidgettexteditorsubject.h"


class iggWidgetTextEditor;

class iqtSyntaxHighlighter;

class QEvent;
class QKeyEvent;
class QMouseEvent;
class QTextEdit;


class iqtWidgetTextEditorSubject : public QTextEdit, public ibgWidgetTextEditorSubject
{

	Q_OBJECT

	friend class iggSubjectFactory;

public:

	virtual ~iqtWidgetTextEditorSubject();

	virtual bool AppendBreaksLine() const;
	virtual bool SupportsHTML() const;
	virtual bool TextModified() const;

	//
	//  Text manipulations
	//
	virtual void Clear();
	virtual void SetModified(bool s);
	virtual void SetText(const iString &text);
	virtual iString GetText() const;
	virtual void AppendText(const iString &text, bool scroll = true);

	//
	//  Line-by-line manipulation
	//
	virtual int GetNumberOfLines() const;
	virtual void RemoveLine(int n);
	virtual iString GetLine(int n) const;

	//
	//  Text attribute manipulations
	//
	virtual void SetBoldText(bool s);
	virtual void SetTextColor(const iColor &color);
	virtual void SetPointSize(int s);
	virtual void SetLineColor(int line, const iColor &color);
	virtual void UnSetLineColor(int line);
	virtual iColor GetLineColor(int line) const;

	//
	//  Selection & cursor location
	//
	virtual void Select(int paraFrom, int indexFrom, int paraTo, int indexTo, bool leftJustified = false, int selNum = 0);
	virtual void GetCursorPosition(int &para, int &index);

	//
	//  Syntax highlighting
	//
	virtual void HighlightSyntax(bool s);
	virtual void AddKeyword(const iString &word, int category);
	virtual void AddCategory(const iColor &color);
	virtual void HighlightComments(const iString &comment, const iColor &color);
	virtual void HighlightStrings(const iColor &color);

	//
	//  Editing functions
	//
	virtual bool HasEditingFunction(int type) const;
	virtual void UseEditingFunction(int type);

	//
	//  Search & find
	//
	virtual bool Find(const iString &text, bool cs, bool wo, bool forward, int &para, int &index);

protected:

	iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode);

	iqtSyntaxHighlighter *mSyntaxHighlighter;
	const int mMode;

	//
	//  Qt specific
	//
	virtual void enterEvent(QEvent *e);
	virtual void keyPressEvent(QKeyEvent *e);
	virtual void contentsMousePressEvent(QMouseEvent *e);
	virtual void contentsMouseReleaseEvent(QMouseEvent *e);
	virtual void contentsMouseDoubleClickEvent(QMouseEvent *e);

public slots:

	void OnTextChanged();
	void OnSelectionChanged();
	void OnCursorPositionChanged(int, int);
	void OnReturnPressed();
};

#endif  //  IQTWIDGETTEXTEDITORSUBJECT_H
